#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 appar
version:              0.1.8
visibility:           public
id:                   appar-0.1.8-AJpyf6kw4BC7M1w0DNi1Qs
key:                  appar-0.1.8-AJpyf6kw4BC7M1w0DNi1Qs
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A simple applicative parser
description:          A simple applicative parser in Parsec style
category:             Parsing
abi:                  83e00b9cbeeda83e38680d5e06326a17
exposed:              True
exposed-modules:
    Text.Appar.ByteString Text.Appar.LazyByteString Text.Appar.String

hidden-modules:       Text.Appar.Input Text.Appar.Parser
import-dirs:          /usr/lib/ghc-8.10.5/site-local/appar-0.1.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/appar-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/appar-0.1.8
hs-libraries:         HSappar-0.1.8-AJpyf6kw4BC7M1w0DNi1Qs
depends:              base-4.14.2.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-appar/html/appar.haddock
haddock-html:         /usr/share/doc/haskell-appar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

